@@ -1,8 +1,5 @@
 package WebService::VerifyEmail;
-{
-  $WebService::VerifyEmail::VERSION = '0.02';
-}
-
+$WebService::VerifyEmail::VERSION = '0.03';
 use 5.006;
 use Moo;
 use Net::HTTP::Tiny qw(http_get);
@@ -99,7 +96,7 @@ L<Mail::CheckUser>, L<Mail::EXPN>, L<Net::validMX>, L<Email::Valid::Loose>.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/WebService-VerifyEmail>
+L<https://github.com/neilb/WebService-VerifyEmail>
 
 =head1 AUTHOR
 
